# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, Context, loader
from ovmtb.resources.ModifyByIDFormPage import ModifyByIDFormPage
from ovmtb.admin.ModifyUserForm import ModifyUserForm
from django.forms import ModelForm, RegexField, CharField, PasswordInput
from django.contrib.auth.models import User
from django.http import HttpResponse, HttpResponseRedirect
from django.utils.translation import ugettext as _

class ModifyUserByIDFormPage(ModifyByIDFormPage):
    '''Form page to add or edit a User object in the database.'''

    def __init__(self, id=None):
        '''Creates a ModfiyUserByIDFormPage.

        :Parameters - 
            - 'id':  The primary key of the User object to modify
        '''
        ModifyByIDFormPage.__init__(self, User, ModifyUserForm,
            { "tab_template": "admin_tab_active.html",
                "submenu_template": "admin_user_submenu.html",
            },
            { "cancelButton1": self.cancel,
                "cancelButton2": self.cancel,
                "saveButton1": self.save,
                "saveButton2": self.save
            },
            "modify_user.html",
            { "cancel": "/ovmtb/admin/users",
                "save": "/ovmtb/admin/users"
            },
            id=id)

    def cancel(self, request):
        '''Cancels any modifcations done to the User object and deletes if necessary.'''
        return HttpResponseRedirect(self.urls['cancel'])

    def save(self, request):
        '''Saves any modifcations done to the User object and deletes if necessary.'''
        form = self.modelFormClass(request.POST)

        if form.is_valid():
            username = form.cleaned_data['username']
            email = form.cleaned_data['email']
            password = form.cleaned_data['password2']
            u = User.objects.create_user(username, email, password)
            u.last_name = form.cleaned_data['last_name']
            u.first_name = form.cleaned_data['first_name']
            u.is_active = form.cleaned_data['is_active']
            u.is_superuser = form.cleaned_data['is_superuser']
            u.save()
            return HttpResponseRedirect(self.urls['save'])
        else:
            self.context_params['form'] = form
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))
