# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, Context, loader
from django.core.exceptions import ObjectDoesNotExist
from django.forms import ModelForm, RegexField, CharField, PasswordInput
from django.contrib.auth.models import User
from django.http import HttpResponse, HttpResponseRedirect
from django.utils.translation import ugettext as _
from ovmtb.resources.ModifyByIDFormPage import ModifyByIDFormPage
from ovmtb.admin.ModifyUserForm import ModifyUserForm

class ModifyUserByIDFormPage(ModifyByIDFormPage):
    '''Form page to add or edit a User object in the database.'''

    def __init__(self, modelClass=None, modelClassForm=None, context_params=None, template=None, id=None):
        '''Creates a ModfiyUserByIDFormPage.

        :Parameters - 
            - 'id':  The primary key of the User object to modify
        '''
        ModifyByIDFormPage.__init__(self, modelClass, modelClassForm, context_params=context_params, template=template, id=id)

        self.urls['save'] = "/ovmtb/admin/users/"
        self.urls['cancel'] = "/ovmtb/admin/users/"
        self.MAGIC_PASSWORD_STRING = '_______________'

        if self.id:
            # Because we want two password fields, the data has to be munged a little bit
            try:
                self.session_data = {}
                o = self.modelClass.objects.get(id=self.id)
                self.session_data['username'] = o.username
                self.session_data['password'] = self.MAGIC_PASSWORD_STRING
                self.session_data['retype_password'] = self.MAGIC_PASSWORD_STRING
                self.session_data['first_name'] = o.first_name
                self.session_data['last_name'] = o.last_name
                self.session_data['email'] = o.email
            except ObjectDoesNotExist:
                pass

    def saveButton(self, request):
        '''Saves any modifcations done to the User object.'''
        self.setupModelForm(data=request.POST)
        if self.id:
            self.form.setOrigUsername(self.session_data['username'])
            self.form.setOrigEmail(self.session_data['email'])

        if self.form.is_valid():
            if self.id:
                u = self.modelClass.objects.get(id=self.id)
                u.username = self.form.cleaned_data['username']
                u.last_name = self.form.cleaned_data['last_name']
                u.first_name = self.form.cleaned_data['first_name']
                u.email = self.form.cleaned_data['email']
                if self.form.cleaned_data['password'] != self.MAGIC_PASSWORD_STRING:
                    u.set_password(self.form.cleaned_data['password'])
                u.save()
                try:
                    request.session['info_messages'].append(_("Saved user: %(user)s") % {'user':u})
                except KeyError, e:
                    request.session['info_messages'] = [_("Saved user: %(user)s") % {'user':u}]
            else:
                username = self.form.cleaned_data['username']
                email = self.form.cleaned_data['email']
                password = self.form.cleaned_data['password']
                u = self.modelClass.objects.create_user(username, email, password)
                u.last_name = self.form.cleaned_data['last_name']
                u.first_name = self.form.cleaned_data['first_name']
                u.save()
                try:
                    request.session['info_messages'].append(_("Created user: %(user)s") % {'user':u})
                except KeyError, e:
                    request.session['info_messages'] = [_("Created user: %(user)s") % {'user':u}]
            return HttpResponseRedirect(self.urls['save'])
        else:
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))
