# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from ovmtb.resources.ModifyByIDFormPage import ModifyByIDFormPage
from django.forms import ModelForm, RegexField, CharField, PasswordInput, ChoiceField, ValidationError
from django.contrib.auth.models import User
from django.http import HttpResponse, HttpResponseRedirect
from django.utils.translation import ugettext as _

class ModifyUserForm(ModelForm):
    """
    A form that creates a user, with no privileges, from the given username and password.
    """
    username = RegexField(label=_("Username"), max_length=30, regex=r'^\w+$',
        help_text = _("Required. 30 characters or fewer. Alphanumeric characters only (letters, digits and underscores)."),
        error_message = _("This value must contain only letters, numbers and underscores."))
    password1 = CharField(label=_("Password"), widget=PasswordInput)
    password2 = CharField(label=_("Retype password"), widget=PasswordInput)

    class Meta:
        model = User
        fields= ('username', 'first_name', 'last_name', 'email')

    def clean_password2(self):
        password1 = self.cleaned_data.get("password1", "")
        password2 = self.cleaned_data["password2"]
        if password1 != password2:
            raise ValidationError(_("The two password fields didn't match."))
        return password2

    def save(self, commit=True):
        user = super(ModifyUserForm, self).save(commit=False)
        if self.cleaned_data["password1"]:
            user.set_password(self.cleaned_data["password1"])
        if commit:
            user.save()
        return user
        
