# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
import os
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from ovmtb.resources.TableFormPage import TableFormPage
from ovmtb.templates.models import TemplateProject
from django.contrib.auth.models import User
from django.utils.translation import ugettext as _
from django.conf import settings

class UserTableFormPage(TableFormPage):
    '''View logic for a page consisting of a table listing YUM repositories and action buttons.

    The TableFormPage class implements the basic view functionality for a page that will display a
    form that contains a table of YUM repositories.  Behavoir should be identical to TableFormPage
    except that the function_map has been defined in the constructor.
    '''
    
    def deleteButton(self, request):
        '''Logic for handling POST request due to the user clicking the 'Delete' button.

        This object handles POST requests the result from the user clicking on the 'Delete' button.  The
        response will be to delete the object selected in the table and redirect to the
        'base_url' URL.

        :Parameters
            - 'request': The request object passed in from the Django framework

        :Returns
            - The return value of the django.http.HttpResponseRedirect object

        :Raises
            - Many different exceptions could be raised.
        '''
        try:
            if self.base_url:
                user = self.modelClass.objects.get(id=request.POST['radioSelect'])

                # First I should delete all project associated with the user
                projects = TemplateProject.objects.filter(owner__exact=user)
                for project in projects:
                    deletefile = open('%s/delete_project_%s' %(settings.OVMTB_BUILD_QUEUE_DIR, project.id), "w")
                    if project.builddir:
                        deletefile.write("%s/%s\n" %(settings.OVMTB_BUILD_DIR, os.path.basename(project.builddir)))
                    if project.tarfile:
                        deletefile.write("%s/%s\n" %(settings.OVMTB_TAR_DIR, os.path.basename(project.tarfile)))
                    if project.logfile:
                        deletefile.write("%s/%s\n" %(settings.OVMTB_LOG_DIR, os.path.basename(project.logfile)))
                    if project.upload_dir:
                        deletefile.write("%s\n" %(project.upload_dir))
                    deletefile.close()
                    project.delete()

                #Now delete the user
                user.delete()
                try:
                    request.session['info_messages'].append(_("Deleted user: %(r)s") %{'r':user})
                except KeyError, e:
                    request.session['info_messages'] = [_("Deleted user: %(r)s") %{'r':user}]
                return HttpResponseRedirect(self.base_url)
            else:
                raise Exception(self.noURLMsg)
        except KeyError, e:
            if self.base_url:
                request.session['info_messages'] = [_("Please select an item from the list")]
                return HttpResponseRedirect(self.base_url)
            else:
                raise Exception(self.noURLMsg)

    def addButton(self, request):
        '''Logic for handling POST request due to the user clicking the 'Add' button.
        
        This object handles POST requests the result from the user clicking on the 'Add' button.  The
        response will be to create an new object and redirect to the
        /ovmtb/resources/yum/add/<repo_id> URL.  This function assumes that the objects constructor
        will have no required parameters, and the model uses Django automatic primary key generator
        and as such has an attribute 'id'.
        
        :Parameters
            - 'request': The request object passed in from the Django framework
            
        :Returns
            - The return value of the django.http.HttpResponseRedirect object
            
        :Raises
            - Many different exceptions could be raised.
        '''
        if self.add_url:
            return HttpResponseRedirect(self.add_url)
        else:
            raise Exception(self.noURLMsg)

    def __init__(self,
        modelClass=None,
        dict_key=None,
        context_params=None,
        template=None):
        '''Creates a YUMTableFormPage object.
    
        :Parameters
            - 'modelClass': The class of objects used to populate the table.  Should be a subclass
              of the django.db.models.Model class.
            - 'dict_key': The context variable to store the list of objects in.  Should be used in the
              template tags.
            - 'context_params': The context parameters passing into the template.
            - 'template': The template to load.
        '''
        TableFormPage.__init__(self, modelClass=modelClass, dict_key=dict_key, context_params=context_params, template=template,
            add_url='/ovmtb/admin/user_profile/add/', edit_url='/ovmtb/admin/user_profile/edit/',base_url='/ovmtb/admin/users/')

