# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, loader
from django.http import HttpResponse, HttpResponseRedirect
from django import forms
from django.shortcuts import render_to_response
from django.forms.util import ErrorList
from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import User
from ovmtb.admin.UserTableFormPage import UserTableFormPage
from ovmtb.admin.ModifyUserByIDFormPage import ModifyUserByIDFormPage
from ovmtb.login.views import UserForm, RegisterForm

@login_required
def users(request):
    context_params = {
        'tab_template': "admin_tab_active.html",
        'submenu_template': "admin_user_submenu.html",
    }
    utfp = UserTableFormPage(modelClass=User, dict_key='user_list', context_params=context_params, template='users.html')
    return utfp.HttpResponse(request)

@login_required
def daemon(request):
    from ovmtb.admin.Daemon import DaemonStep
    d = DaemonStep( template = 'admin_daemon.html',
        previous_url = '/ovmtb/admin/daemon/')
    return d.generateResponse(request)

@login_required
def user_profile(request, user_id=None):
    context_params = {
        'tab_template': "admin_tab_active.html",
        'submenu_template': "admin_user_submenu.html",
    }
    if user_id:
        mup = ModifyUserByIDFormPage(modelClass=User, modelClassForm=UserForm, context_params=context_params, template="modify_user.html", id=user_id)
    else:
        mup = ModifyUserByIDFormPage(modelClass=User, modelClassForm=UserForm, context_params=context_params, template="modify_user.html", id=request.user.id)
    return mup.HttpResponse(request)

@login_required
def add_user(request):
    context_params = {
        'tab_template': "admin_tab_active.html",
        'submenu_template': "admin_user_submenu.html",
    }
    mup = ModifyUserByIDFormPage(modelClass=User, modelClassForm=RegisterForm, context_params=context_params, template="add_user.html")
    return mup.HttpResponse(request)
