# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along

import os, sys, shutil, tarfile
from threading import Thread, Event
from time import sleep
from subprocess import Popen, PIPE
from string import strip, replace
from build_constants import *

sys.path.append('/var/www/html')
os.environ['DJANGO_SETTINGS_MODULE'] ='ovmtb.settings'

from django.core.management import setup_environ
from ovmtb import settings
from ovmtb.templates.models import TemplateProject, HardwareDescription, DiskImage, UserPackage

setup_environ(settings)

class JeOSCleanThread(Thread):
    '''Thread to clean up a template project that has been built.'''

    def __init__(self, clean_file, project_id, build_thread=None):
        '''Creates a thread that will clean up a template project that has been built

        :Parameters
            - 'clean_file' : The file created by the web interface indicating the project to clean
            - 'project_id' : The database id of the project to clean
        ''' 
        Thread.__init__(self)
        self.clean_file = clean_file
        self.project_id = project_id
        self.build_thread = build_thread
        self.status = BUILD_QUEUED

    def __checkStopEvent(self):
        if not self.stopEvent.isSet():
            self.stopEvent.wait(0.1)
            if self.stopEvent.isSet():
                return True
            else:
                return False
        else:
            return True

    def run(self):
        # If build_thread is set, that means there is a build in progress.
        # we should wait for it to complete before cleaning up
        self.status = BUILD_RUNNING
        if self.build_thread:
            self.build_thread.join()

        project = TemplateProject.objects.get(id=self.project_id)

        # Remove tarball
        if project.tarfile:
            tarfile = os.path.basename(project.tarfile)
            tarpath = "%s/%s" %(settings.OVMTB_TAR_DIR, tarfile)
            if os.access(tarpath, os.F_OK):
                try:
                    os.remove(tarpath)
                    project.tarfile = ""
                except Exception, e:
                    pass
        project.status_percent = 33
        project.save()

        # Remove build dir
        if project.builddir:
            builddir = "%s/%s" %(settings.OVMTB_BUILD_DIR, os.path.basename(project.builddir))
            if os.access(builddir, os.F_OK):
                try:
                    shutil.rmtree(builddir)
                    project.builddir = ""
                except Exception, e:
                    pass
        project.status_percent = 66
        project.save()

        # Remove build log
        if project.logfile:
            if os.access(project.logfile, os.F_OK):
                try:
                    os.remove(project.logfile)
                    project.logfile = ""
                except Exception, e:
                    pass
        project.status_percent = 100
        project.save()

        # Update template project
        project.status = 'CLN'
        project.built = None
        project.save()

        self.status = BUILD_COMPLETE

if __name__ == '__main__':
    ct = JeOSCleanThread("test", 1)
    ct.start()
    ct.join()
