# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import Context, loader
from django.template.loader import get_template
from django.http import HttpResponse, HttpResponseRedirect
from django import forms
from django.shortcuts import render_to_response
from django.forms.util import ErrorList
from django.contrib.auth.models import User
from django.contrib import auth
from django.contrib.auth.forms import AuthenticationForm
from django.contrib.auth.views import login
from django.utils.translation import ugettext as _


class UserForm(forms.ModelForm):
    username = forms.CharField(max_length=100,
                widget=forms.TextInput(attrs={'id':'form1:inputText1',
                                                'name':'form1:inputText1',
                                                'class':'x8',
                                                'size':'30'}))
    password = forms.CharField(max_length=100,
                widget=forms.PasswordInput(attrs={'id':'form1:userPassword',
                                                'name':'form1:userPassword',
                                                'onkeydown':'return _clearPassword(this, event);',
                                                'class':'x8',
                                                'size':'30'}))
    retype_password = forms.CharField(max_length=100,
                widget=forms.PasswordInput(attrs={'id':'form1:retypePassword',
                                                'name':'form1:retypePassword',
                                                'onkeydown':'return _clearPassword(this, event);',
                                                'class':'x8',
                                                'size':'30'}))
    first_name = forms.CharField(max_length=50, required=False,
                widget=forms.TextInput(attrs={'id':'form1:inputText13',
                                                'name':'form1:inputText13',
                                                'class':'x8',
                                                'size':'30'}))
    last_name = forms.CharField(max_length=50, required=False,
                widget=forms.TextInput(attrs={'id':'form1:inputText14',
                                                'name':'form1:inputText14',
                                                'class':'x8',
                                                'size':'30'}))
    email = forms.EmailField(max_length=100,
                widget=forms.TextInput(attrs={'id':'form1:inputText15',
                                                'name':'form1:inputText15',
                                                'class':'x8',
                                                'size':'30'}))
  
    class Meta:
        model = User
        fields = ('username', 'password', 'first_name', 'last_name', 'email')

    def setOrigUsername(self, username):
        self.orig_username = username

    def setOrigEmail(self, email):
        self.orig_email = email

    def is_valid(self):
        if forms.ModelForm.is_valid(self) == False:
           return False
        # only one username and one email in db
        username = self.cleaned_data.get("username")
        #if len(username) != 0:
        if len(username) != 0 and username != self.orig_username:
           try:
              user = User.objects.get(username=username)
           except User.DoesNotExist:
              pass
           else:
               msg = _("This username is already in use. Please choose another.")
               self._errors["username"] = ErrorList([msg])
               return False
        email = self.cleaned_data.get("email")
        #if len(email) !=0:
        if len(email) !=0 and email != self.orig_email:
           try:
              user = User.objects.get(email=email)
           except User.DoesNotExist:
              return True
           msg = _("This email address is already in use for another user account. Please choose another.")
           self._errors["email"] = ErrorList([msg])
           return False
        return True

    def clean(self):
        cleaned_data = self.cleaned_data
        passwd = cleaned_data.get("password")
        retypepasswd = cleaned_data.get("retype_password")

        if not passwd == retypepasswd:
            msg = _("The password fields were different.")
            self._errors["password"] = ErrorList([msg])
            self._errors["retype_password"] = ErrorList([msg])

            if cleaned_data.has_key("password"):
                del cleaned_data["password"]
            if cleaned_data.has_key("retype_password"):
                del cleaned_data["retype_password"]

        return cleaned_data

class RegisterForm(UserForm):
    def is_valid(self):
        if forms.ModelForm.is_valid(self) == False:
           return False
        # only one username and one email in db
        username = self.cleaned_data.get("username")
        if len(username) != 0:
           try:
              user = User.objects.get(username=username)
           except User.DoesNotExist:
              pass
           else:
               msg = _("This username is already in use. Please choose another.")
               self._errors["username"] = ErrorList([msg])
               return False
        email = self.cleaned_data.get("email")
        if len(email) !=0:
           try:
              user = User.objects.get(email=email)
           except User.DoesNotExist:
              return True
           msg = _("This email address is already in use for another user account. Please choose another.")
           self._errors["email"] = ErrorList([msg])
           return False

class ForgotPasswordForm(forms.Form):
    reqPwdUserName = forms.CharField(max_length=100,
                widget=forms.TextInput(attrs={'id':'form1:inputReqPwdUserName',
                                                'name':'form1:inputReqPwdUserName',
                                                'class':'x8',
                                                'size':'30'}))
    def is_valid(self):
        if forms.Form.is_valid(self) == False:
           return False
        # only one username in db
        reqPwdUserName = self.cleaned_data.get("reqPwdUserName")
        try:
            user = User.objects.get(username=reqPwdUserName)
        except User.DoesNotExist:
            msg = _("No account matches that user name.")
            self._errors["reqPwdUserName"] = ErrorList([msg])
            return False 
        return user


def register(request):
    # The form will post to the same page.  We will need to handle the inputs for a POST request
    if request.method == 'POST':

        # If the input dictionary has a cancelButton* key, it means the user clicked the Cancel button
        # and should be redirected to the login page
        if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
            return HttpResponseRedirect('/ovmtb/login/')

        # Otherwise we should validate the data provided
        else:
            form = RegisterForm(request.POST)

            # If data is valid create user 
            if form.is_valid():
                request.session['register_info'] = form.cleaned_data
                return HttpResponseRedirect('/ovmtb/register/confirm/')

            # There was a problem with the data provided, show registration form
            # with errors indicated
            else:
                return render_to_response('register.html', {'form': form})

    # We have arrived here from a GET request, from login page or confirm previous button
    else:
        register_info = request.session.get('register_info', {})
        # Arrived here from confirmation page, user info is in session.
        if len(register_info) != 0:
            form = RegisterForm(register_info)
            del request.session['register_info']
            return render_to_response('register.html',{'form':form,})
        # display blank form
        else:
            form = RegisterForm()
            return render_to_response('register.html', {'form': form,})


def confirm(request):

    register_info = request.session.get('register_info', {})
    # The form will post to the same page.  We will need to handle the inputs for a POST request
    if request.method == 'POST':

        # If the input dictionary has a cancelButton* key, it means the user clicked the Cancel button
        # and should be redirected to the login page
        if 'confirmCancelButton2' in request.POST or 'confirmCancelButton1' in request.POST:
            del request.session['register_info']
            return HttpResponseRedirect('/ovmtb/login/')
       
        elif 'confirmPreviousButton2' in request.POST or 'confirmPreviousButton1' in request.POST:
            return HttpResponseRedirect('/ovmtb/register/')

        elif 'confirmConfirmButton2' in request.POST or 'confirmConfirmButton1' in request.POST:
            user = User.objects.create_user(register_info['username'],
                                            register_info['email'],
                                            register_info['password'])
            user.first_name = register_info['first_name']
            user.last_name = register_info['last_name']
            user.save()

            del request.session['register_info']
            
            #userCreated = 'User created.'
            #form = AuthenticationForm(request)
            return HttpResponseRedirect('/ovmtb/login/usercreated/')
            #return render_to_response('login.html', {'userCreated': userCreated, 'form':form,})
    else:
        return render_to_response('confirm_user.html', register_info)


def forgotpassword(request):

     return HttpRespoinseRedirect('/ovmtb/password_reset/')
    # The form will post to the same page.  We will need to handle the inputs for a POST request
    #if request.method == 'POST':
        # If the input dictionary has a cancelButton* key, it means the user clicked the Cancel button
        # and should be redirected to the login page
    #    if 'reqPwdCancelButton1' in request.POST or 'reqPwdCancelButton2' in request.POST:
    #        return HttpResponseRedirect('/ovmtb/login/')
        
    #    elif 'reqPwdConfirmButton1' in request.POST or 'reqPwdConfirmButton2' in request.POST:
    #        form = ForgotPasswordForm(request.POST)

            # If data is valid send email
    #        if form.is_valid():
    #           return HttpRespoinseRedirect('/ovmtb/login/resetpassword/')
    #        else:
    #           return render_to_response('forgot_password.html', {'form':form,})
    #else:
    #   form = ForgotPasswordForm()
    #   return render_to_response('forgot_password.html', {'form':form,})
        
 
