# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from xml.sax.handler import EntityResolver

class CompsEntityResolver(EntityResolver):
    '''The comps.xml files included in the various OEL ISOs refrence the comps.xml
    external entity and do not supply a proper full path or URI to the file.  In
    order to parse the file using SAX, an instance of the CompsEntityResolver can be
    used.  A CompsEntityResolver object will redirect any attempt to resolve "comps.dtd"
    to "/var/www/html/ovmtb/scripts/comps.dtd" which should be provided by the ovmtb
    package.
    ''' 

    def resolveEntity(self, publicID, systemID):
        '''Redifinition of resolveEntity object.
        
        :Returns
            - '/var/www/html/ovmtb/scripts/comps.dtd': If the value of systemID is "comps.dtd".
            - 'systemID': Otherwise.
        '''
        if systemID == 'comps.dtd':
            return '/var/www/html/ovmtb/scripts/comps.dtd'
        else:
            return systemID
