# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from xml.sax.handler import ContentHandler

class EL4CompsHandler(ContentHandler):
    '''Implementation of a SAX ContentHandler to parse the contents of the comps.xml file.
    
    This class implements the requires callbacks required in order to perform a SAX style parsing of
    the comps.xml file that is included in the /Enterprise/base directory of an OEL4 ISO.  As the file is
    parsed, the names of all packages and groups defined in the file will be collected as lists. The list of
    groups is accessible via the groups_list attribute of the object.  The list of packages is accessible via
    the package_list attribute of the object.
    '''
    
    def __init__(self):
        self.inGroupDef = False
        self.inGroupIDDef = False
        self.inPackageListDef = False
        self.inPackageReqDef = False
        self.groups_list = []
        self.package_list = []

    def startElement(self, name, attrs):
        if name == 'group':
            self.inGroupDef = True
        elif self.inGroupDef and name == 'id':
            self.inGroupIDDef = True
        elif self.inGroupDef and name == 'packagelist':
            self.inPackageListDef = True
        elif self.inGroupDef and self.inPackageListDef and name == 'packagereq':
            self.inPackageReqDef = True

    def endElement(self, name):
        if name == 'group':
            self.inGroupDef = False
        elif self.inGroupDef and name == 'id':
            self.inGroupIDDef = False
        elif self.inGroupDef and name == 'packagelist':
            self.inPackageListDef = False
        elif self.inGroupDef and self.inPackageListDef and name == 'packagereq':
            self.inPackageReqDef = False

    def characters(self, content):
        if self.inGroupDef and self.inGroupIDDef:
            self.groups_list.append(content)
        if self.inPackageListDef and self.inPackageReqDef:
            self.package_list.append(content)
