# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from xml.sax.handler import ContentHandler

class EL5CompsHandler(ContentHandler):
    '''Implementation of a SAX ContentHandler to parse the contents of the comps.xml file.
    
    This class implements the requires callbacks required in order to perform a SAX style parsing of
    the various comps.xml files that are included in various directories of an OEL5 ISO.  As the file is
    parsed, the names of all groups defined in the file will be collected as a list accessible via the
    groups_list attribute of the object.
    '''
    
    def __init__(self):
        self.inGroupDef = False
        self.inGroupIDDef = False
        self.inPackageDef = False
        self.groups_list = []

    def startElement(self, name, attrs):
        if name == 'group':
            self.inGroupDef = True
        elif self.inGroupDef and name == 'id':
            self.inGroupIDDef = True

    def endElement(self, name):
        if name == 'group':
            self.inGroupDef = False
        elif self.inGroupDef and name == 'id':
            self.inGroupIDDef = False

    def characters(self, content):
        if self.inGroupDef and self.inGroupIDDef:
            self.groups_list.append(content)

