# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from xml.sax.handler import ContentHandler

class EL5PrimaryHandler(ContentHandler):
    '''Implementation of a SAX ContentHandler to parse the contents of the primary.xml.gz file.
    
    This class implements the requires callbacks required in order to perform a SAX style parsing of
    the primary.xml.gz file that is included in various directories of an OEL5 ISO.  As the file is
    parsed, the names of all packages defined in the file will be collected as a list accessible via the
    package_list attribute of the object.
    '''
    
    def __init__(self):
        self.package_name = None
        self.pacakge_arch = None
        self.package_list = []
        self.inPackageDef = False
        self.inPackageNameDef = False
        self.inPackageArchDef = False

    def startElement(self, name, attrs):
        if name == 'package':
            self.inPackageDef = True
        elif self.inPackageDef and name == 'name':
            self.inPackageNameDef = True
        elif self.inPackageDef and name == 'arch':
            self.inPackageArchDef = True

    def endElement(self, name):
        if name == 'package':
            self.package_list.append("%s.%s" %(self.package_name, self.package_arch))
            self.package_name = None
            self.package_arch = None
            self.inPackageDef = False
        elif self.inPackageDef and name == 'name':
            self.inPackageNameDef = False
        elif self.inPackageDef and name == 'arch':
            self.inPackageArchDef = False

    def characters(self, content):
        if self.inPackageNameDef:
           self.package_name = content
        elif self.inPackageArchDef:
           self.package_arch = content

