# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from ovmtb.resources.ModifyByIDFormPage import ModifyByIDFormPage
from ovmtb.resources.models import JeOSImage, EditJeOSImageForm
from django.utils.translation import ugettext as _

class ModifyJeOSImageByIDFormPage(ModifyByIDFormPage):
    '''Concrete version of a ModifyByIDFormPage for modifying a JeOSImage object.  
    '''

    def saveButton(self, request):
        '''Overrides the ModifyByIDFormPage.saveButton method. 

        :Parameters
            - 'request': The request object passed in by the Django framework
        :Returns
            An HttpResponse object
        '''
        self.setupModelForm(data=request.POST)

        if self.form.is_valid():
            image = self.form.save()
            try:
                request.session['info_messages'].append(_("Saved JeOS image %(r)s") %{'r':image})
            except KeyError, e:
                request.session['info_messages'] = [_("Saved JeOS image %(r)s") %{'r':image}]
            return HttpResponseRedirect(self.urls['save'])
        else:
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))

    def __init__(self, context_params=None, template=None, id=None):
        ModifyByIDFormPage.__init__(self, JeOSImage, EditJeOSImageForm, context_params=context_params, template=template, id=id)

        # Setup urls
        self.urls['cancel'] = '/ovmtb/resources/jeos/'
        self.urls['save'] = '/ovmtb/resources/jeos/'
