# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.utils.translation import ugettext as _
from ovmtb.resources.ModifyByIDFormPage import ModifyByIDFormPage
from ovmtb.resources.models import YUMRepo, EditYUMForm
from ovmtb.templates.common import *
from YUMTableFormPage import cacheYUM
import datetime

class ModifyYUMByIDFormPage(ModifyByIDFormPage):
    '''Concrete version of a ModifyByIDFormPage.  The only change is to override the saveButton to
    save the EditYUMForm into a YUMRepo object and cache it if the user desires.
    '''

    def saveButton(self, request):
        '''Overrides the ModifyByIDFormPage.saveButton method.  If the request POST data has a 
        entry at the 'cacheCheckbox', the list packages defined in the YUM repository will be 
        cached in the database.

        :Parameters
            - 'request': The request object passed in by the Django framework
        :Returns
            An HttpResponse object
        '''
        self.setupModelForm(data=request.POST)

        if self.form.is_valid():
            repo = self.form.save()
            log_info_message(request, _("Saved Yum repository: %(r)s") %{'r':repo})

            if 'cacheCheckbox' in request.POST:
                try:
                    cacheYUM(repo)
                    repo.cached = datetime.datetime.now()
                    repo.save()
                    log_info_message(request, _("Cached Yum repository: %(r)s") %{'r':repo})
                except Exception, e:
                    repo.cached = None
                    repo.packages = ""
                    repo.groups = ""
                    repo.save()
                    try:
                        del self.context_params['info_messages']
                    except KeyError:
                        pass
                    log_error_message(request, _("Could not cache Yum reposistory %(r)s: %(err)s") %{'r':repo, 'err':e})
            else:
                repo.cached = None
                repo.packages = ""
                repo.groups = ""
                repo.save()
            return HttpResponseRedirect(self.urls['save'])

        else:
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))

    def __init__(self, context_params=None, template=None, id=None):
        ModifyByIDFormPage.__init__(self, YUMRepo, EditYUMForm, context_params=context_params, template=template, id=id)

        # Setup urls
        self.urls['cancel'] = '/ovmtb/resources/yum/'
        self.urls['save'] = '/ovmtb/resources/yum/'
