# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.db import models
from django.forms import ModelForm, CharField
from django.utils.translation import ugettext as _

class JeOSImage(models.Model):
    TYPE_CHOICES = (
        ('HVM', _("Hardware Virtualized Machine")),
        ('PVM', _("Para-virtualized Machine")),
    )
    
    image_name = models.CharField(unique=True, max_length=50, editable=False)
    description = models.CharField(default=_("User defined image"), max_length=200)
    type = models.CharField(default='None', max_length=200, choices=TYPE_CHOICES)
    active = models.BooleanField(default=True, editable=False)

    def __unicode__(self):
        return self.image_name

class YUMRepo(models.Model):

    repository_name = models.CharField(default=_("New Repo"), max_length=30)
    url = models.URLField(verify_exists=False)
    packages = models.TextField(default="", null=True, blank=False, editable=False)
    groups = models.TextField(default="", null=True, blank=False, editable=False)
    cached = models.DateTimeField(null=True, blank=True)

    def __unicode__(self):
        return self.repository_name

class DVDISOLocation(models.Model):

    location_description = models.CharField(default=_("New DVD location"), max_length=30)
    path_to_ISO = models.CharField(default="", max_length=200)
    packages = models.TextField(default="", null=True, blank=False, editable=False)
    groups = models.TextField(default="", null=True, blank=False, editable=False)
    cached = models.DateTimeField(null=True, blank=True, editable=False)

    def __unicode__(self):
        return self.location_description

class EditYUMForm(ModelForm):
    class Meta:
        model = YUMRepo

class EditDVDForm(ModelForm):
    location_description = CharField(label=_("DVD ISO name"))

    class Meta:
        model = DVDISOLocation

class EditJeOSImageForm(ModelForm):
    class Meta:
        model = JeOSImage
