# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django import forms
from django.shortcuts import render_to_response
from django.forms.util import ErrorList
from django.contrib.auth.decorators import login_required
from ovmtb.resources.models import YUMRepo, EditYUMForm, DVDISOLocation, EditDVDForm, JeOSImage, EditJeOSImageForm
from subprocess import Popen, PIPE
from ovmtb.resources.YUMTableFormPage import YUMTableFormPage
from ovmtb.resources.DVDTableFormPage import DVDTableFormPage
from ovmtb.resources.JeOSImageTableFormPage import JeOSImageTableFormPage
from ovmtb.resources.DVDISOParser import make_parser
from ovmtb.resources.ModifyYUMByIDFormPage import ModifyYUMByIDFormPage
from ovmtb.resources.ModifyDVDByIDFormPage import ModifyDVDByIDFormPage
from ovmtb.resources.ModifyJeOSImageByIDFormPage import ModifyJeOSImageByIDFormPage
import random, datetime

@login_required
def yum(request):
    context_params = {
        'tab_template': "resources_tab_active.html",
        'submenu_template': "resources_yum_submenu.html",
    }
    ytfp = YUMTableFormPage(modelClass=YUMRepo, dict_key='repo_list', context_params=context_params, template='yum_repos.html')
    return ytfp.HttpResponse(request)

@login_required
def yumedit(request, repo_id=None, type=None):
    if type == 'add':
        template = "add_yum.html"
    else:
        template = "edit_yum.html"

    context_params = {
        'tab_template': "resources_tab_active.html",
        'submenu_template': "resources_yum_submenu.html",
    }

    myr = ModifyYUMByIDFormPage(template=template, context_params=context_params, id=repo_id)
    return myr.HttpResponse(request)

@login_required
def dvds(request):
    context_params = {
        'tab_template': "resources_tab_active.html",
        'submenu_template': "resources_dvds_submenu.html",
    }
    dtfp = DVDTableFormPage(modelClass=DVDISOLocation, dict_key='dvd_list', context_params=context_params, template='dvd_isos.html')
    return dtfp.HttpResponse(request)

@login_required
def dvdedit(request, dvd_id=None, type=None):
    if type == 'add':
        template = "add_dvd.html"
    else:
        template = "edit_dvd.html"

    context_params = {
        'tab_template': "resources_tab_active.html",
        'submenu_template': "resources_dvds_submenu.html",
    }

    mdr = ModifyDVDByIDFormPage(template=template, context_params=context_params, id=dvd_id)
    return mdr.HttpResponse(request)

@login_required
def jeos(request):
    context_params = {
        'tab_template': "resources_tab_active.html",
        'submenu_template': "resources_jeos_submenu.html",
    }
    jfp = JeOSImageTableFormPage(modelClass=JeOSImage, dict_key='jeos_list', context_params=context_params, template='jeos_images.html')
    return jfp.HttpResponse(request)

@login_required
def jeosedit(request, jeos_id=None):
    ji = ModifyJeOSImageByIDFormPage(template="edit_jeos.html", id=jeos_id)
    return ji.HttpResponse(request)
