# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.forms import ModelForm, Form, FileField, CharField
from django.utils.translation import ugettext as _
from django.forms.widgets import Textarea
from django.conf import settings
from subprocess import Popen, PIPE
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.models import TemplateProject
from ovmtb.templates.common import *
import os, re

class AddEULAStep(WizardStep):
    '''The Description class implements the logic behind the 'OVM Template
    Project Description' page.
    '''

    def __init__(self,
            template = 'add_eula.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/description/',
            save_url = '/ovmtb/templates/description/',
            previous_url = '/ovmtb/templates/description/',
            next_url = '/ovmtb/templates/description/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def verifyFileIsText(self, path):
        '''Verifies that an uploaded file or downloaded URL is actually a text file
        
        :Parameters
            - path : Path to the file to verify
        :Returns
            - None
        :Throws
            - An exception is the file is not a text file
        '''
        file_cmd = "/usr/bin/file %s" %(path)
        p = Popen(file_cmd, shell=True, bufsize=0, stdout=PIPE, stderr=PIPE, close_fds=False)
        line = p.stdout.read()
        if not re.search('text|character data', line):
            raise Exception(line)
        
    def handle_uploaded_eula(self, request, project_id):
        '''Utility function to handle the uploading of the EULA from a text file.
        
        :Parameters
            - 'request': The request object passed in from the Django framework
            - 'project_id': The template project for which this EULA should be
            stored
        :Returns
            - None
        :Throws
            - An Exception if there was a problem uploading the EULA, or the file
            provided was not text. 
        '''
        f = request.FILES['eula_file']
        # First I need to verify that the file is text.  Large files will
        # be downloaded to the disk and the UploadedFile object's temporary_file_path
        # attribute will be set.  If it is use that to verify, otherwise the file is
        # small so Django kept it in memory.  I need to download to disk prior
        # to verifying.
        try:
            path = f.temporary_file_path
            downloaded = False
        except Exception:
            path = "%s/%s.%s" %(settings.OVMTB_UPLOAD_DIR, f.name, os.getpid())
            destination = open(path, "wb+")
            for chunk in f.chunks():
                destination.write(chunk)
            destination.close()
            downloaded = True
        
        try:
            self.verifyFileIsText(path)
        except Exception, e:
            if downloaded:
                os.remove(path)
            raise e

        eula = ""
        for chunk in f.chunks():
            eula += chunk
        
        # If I manually downloaded the file, remove it
        if downloaded:
            os.remove(path)
        
        # Load the data from the session, change the EULA and save
        data = loadWork(request, project_id=project_id)
        data['TemplateProject'].EULA = eula
        saveWork(request, project_id=project_id, data=data)

    def generateResponse(self, request, project_id=None):
        if request.method == 'POST':

            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                return HttpResponseRedirect(map_url(self.cancel_url, project_id=project_id))
                
            form = AddEULAForm(request.POST, request.FILES)
            self.context_params['form'] = form

            if 'addButton2' in request.POST or 'addButton1' in request.POST:
                if form.is_valid():
                    try:
                        self.handle_uploaded_eula(request, project_id)
                        return HttpResponseRedirect(map_url(self.save_url, project_id=project_id))
                    except Exception, e:
                        self.context_params['error_messages'] = [_("Problem uploading EULA file: %(msg)s") % {'msg':e}]

            # If there was some error, redisplay the page
            t = loader.get_template(self.template)
            get_messages(request, self.context_params)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))

        else:
            form = AddEULAForm()
            self.context_params['form'] = form
            t = loader.get_template(self.template)
            get_messages(request, self.context_params)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))

class AddEULAForm(Form):
    eula_file  = FileField(label=_("EULA file location"))
