# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.utils.translation import ugettext as _
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.common import *
from ovmtb.templates.models import TemplateProject, UserPackage, HardwareDescription
from django.forms import ModelForm, FileField, CharField, ValidationError
from subprocess import Popen, PIPE
from urlgrabber.grabber import URLGrabber
import rpm, os, random, shutil, re

class AddPackageStep(WizardStep):

    def __init__(self,
            template = 'add_package.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/additional_packages/',
            save_url = '/ovmtb/templates/additional_packages/',
            previous_url = '/ovmtb/templates/additional_packages/',
            next_url = '/ovmtb/templates/additional_packages/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url
        checkDir(settings.OVMTB_UPLOAD_DIR)

    def verifyFileIsRPM(self, path):
        '''Verifies that an uploaded file or downloaded URL is actually an RPM package
        
        :Parameters
            - path : Path to the file to verify
        :Returns
            - None
        :Throws
            - An exception is the file is not an rpm
        '''
        file_cmd = "/usr/bin/file %s" %(path)
        p = Popen(file_cmd, shell=True, bufsize=0, stdout=PIPE, stderr=PIPE, close_fds=False)
        line = p.stdout.read()
        if not re.search('RPM', line):
            os.remove(path)
            raise Exception(line)
        
    def handle_file_upload(self, f, data, project_id=None):
        '''Handles file upload when user supplies a rpm from their local filesystem.
        
        :Parameters
            - f : An object passed in by the Django framework containing information about
            the uploaded file as it is stored temporarily by the framework
            - 'data': The session data to work with
            - project_id : The ID of the project for which this package will be installed
        :Return
            - None
        '''
        u = UserPackage()
        project = data['TemplateProject']
        u.template_project = project

        save_path = '%s/%s' %(project.upload_dir, f.name)
        destination = open(save_path, 'wb+')
        for chunk in f.chunks():
            destination.write(chunk)
        destination.close()

        self.verifyFileIsRPM(save_path)
        
        s1 = r'/bin/rpm --nosignature -qp --qf "%{NAME}"'
        s2 = ' %s' %(save_path)
        rpm_cmd = s1 + s2

        p = Popen(rpm_cmd, shell=True, bufsize=0, stdout=PIPE, stderr=PIPE, close_fds=False)
        out = p.stdout

        u.package_file = save_path
        u.package_name = out.readline()
        u.url=""
        data['package_list'].append(u)

    def handle_url_download(self, url, data, project_id=None):
        '''Utility function that will handle downloading a URL provided by the user.
        
        :Parameters
            - 'url' : The URL to download
            - 'data': The session data to work with
            - 'project_id' : The ID of the project for which this package will be installed
        :Returns
            - None
        '''
        u = UserPackage()
        project = data['TemplateProject']
        u.template_project = project


        file_name = os.path.basename(url)
        save_path = "%s/%s" %(project.upload_dir, file_name)

        g = URLGrabber()
        try:
            rpm_file = g.urlgrab(url, filename=save_path)
        except Exception, e:
            os.remove(save_path)
            raise e

        self.verifyFileIsRPM(save_path)
        
        s1 = r'/bin/rpm --nosignature -qp --qf "%{NAME}"'
        s2 = ' %s' %(save_path)
        rpm_cmd = s1 + s2

        p = Popen(rpm_cmd, shell=True, bufsize=0, stdout=PIPE, stderr=PIPE, close_fds=False)
        out = p.stdout

        u.package_name=out.readline()
        u.package_file=save_path
        u.url=url
        data['package_list'].append(u)
        
    def generateResponse(self, request, project_id):
        # Load the data from the session
        data = loadWork(request, project_id=project_id)

        if request.method == 'POST':
            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                saveWork(request, project_id=project_id, data=data)
                return HttpResponseRedirect(map_url(self.cancel_url, project_id))

            if 'addButton2' in request.POST or 'addButton1' in request.POST:
                form = AddPackageForm(request.POST, request.FILES)
                self.context_params['checked'] = request.POST['urlOrFileRadio']
                
                # urlOrFileRadio = 1 means the user selected a file to upload
                # urlOrFileRadio = 0 means the user provided a url 
                if 'urlOrFileRadio' in request.POST and request.POST['urlOrFileRadio'] == '1':
                    if 'package_file' in request.FILES:
                        try:
                            self.handle_file_upload(request.FILES['package_file'], data, project_id=project_id)
                        except Exception, e:
                            log_error_message(request, _("An error occured during file uploading: %(msg)s") % {'msg':e})
                            self.context_params['checked'] = 1
                    else:
                        log_error_message(request, _("Please select a package from your local disk to upload"))
                        self.context_params['checked'] = 1
                else:
                    if request.POST['url']:
                        try:
                            self.handle_url_download(request.POST['url'].strip(), data, project_id=project_id)
                        except Exception, e:
                            self.context_params['checked'] = 0
                            log_error_message(request, _("An error occured when attempting to download the url: %(msg)s") % {'msg':e})
                    else:
                        self.context_params['checked'] = 0
                        log_error_message(request, _("Please provide a URL to download"))

                get_messages(request, self.context_params)
                saveWork(request, project_id=project_id, data=data)
                if 'error_messages' in self.context_params:
                    self.context_params['form'] = form
                    t = loader.get_template(self.template)
                    c = RequestContext(request, self.context_params)
                    return HttpResponse(t.render(c))
                else:
                    return HttpResponseRedirect(map_url(self.save_url, project_id))
        else:
            self.context_params['checked'] = 0
            self.context_params['form'] = AddPackageForm()
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            saveWork(request, project_id=project_id, data=data)
            return HttpResponse(t.render(c))

class AddPackageForm(ModelForm):
    package_file = FileField(label=_("File"))

    class Meta:
        model = UserPackage
        fields = ('package_file', 'url')

