# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.common import *
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from ovmtb.templates.models import TemplateProject, UserPackage, HardwareDescription
from django.forms import ModelForm, FileField, CharField, ValidationError
from subprocess import Popen, PIPE
from urlgrabber.grabber import URLGrabber
from django.utils.translation import ugettext as _
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
import rpm, os, random, shutil, re

class AdditionalPackagesStep(WizardStep):

    def __init__(self,
            template = 'additional_packages.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/save/',
            previous_url = '/ovmtb/templates/operating_system/',
            next_url = '/ovmtb/templates/confirm/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id=None):
        # Load the data from the session
        data = loadWork(request, project_id=project_id)
        hardware = data['HardwareDescription']

        if request.method == 'POST':
            script_form = AddScriptForm(request.POST, instance=hardware)

            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                clearWork(request, data=data, project_id=project_id)
                return HttpResponseRedirect(self.cancel_url)

            if script_form.is_valid():
                script_form.save(commit=False)
                if 'nextButton1' in request.POST or 'nextButton2' in request.POST:
                    base_url = self.next_url
                if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                    base_url = self.save_url
                if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                    base_url = self.previous_url
                if 'addPackageButton' in request.POST:
                    base_url = '/ovmtb/templates/additional_packages/add/'

                if 'deletePackageButton' in request.POST:
                    try:
                        u = data['package_list'].pop(int(request.POST['packageSelect']))
                        data['deleted_packages'].append(u)
                    except KeyError:
                        log_error_message(request, _('Please select a package from the list'))
                    except ObjectDoesNotExist:
                        pass
                    base_url = '/ovmtb/templates/additional_packages/'
                
                saveWork(request, project_id=project_id, data=data)
                return HttpResponseRedirect(map_url(base_url, project_id=project_id))

            # The data in the form was not valid, or there were other problems handling the action
            # so redisplay the page.
            package_list = data['package_list']
            self.context_params['script_form'] = script_form
            self.context_params['package_list'] = package_list
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            saveWork(request, project_id=project_id, data=data)
            return HttpResponse(t.render(c))

        else:
            package_list = data['package_list']
            self.context_params['script_form'] = AddScriptForm(instance=hardware)
            self.context_params['package_list'] = package_list
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            saveWork(request, project_id=project_id, data=data)
            return HttpResponse(t.render(c))

class AddScriptForm(ModelForm):
    config_script = CharField(label=_("Template configuration script"), required=False)
    clean_up_script = CharField(label=_("Template clean up script"), required=False)

    class Meta:
        model = HardwareDescription
        fields = ('config_script', 'clean_up_script')

    def clean_config_script(self):
        '''Customized validation to ensure that the config script path starts with '/'
        '''
        data = self.cleaned_data['config_script']
        if data:
            if not re.match('/', data):
                raise ValidationError(_("Path to configuration script should be absolute (starts with /)"))
        return data

    def clean_clean_up_script(self):
        '''Customized validation to ensure that the clean up script path starts with '/'
        '''
        data = self.cleaned_data['clean_up_script']
        if data:
            if not re.match('/', data):
                raise ValidationError(_("Path to clean up script should be absolute (starts with /)"))
        return data
    
