# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.forms import ModelForm
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.common import *
from ovmtb.templates.models import TemplateProject, HardwareDescription, JeOSImage, DiskImage, UserPackage

class ConfirmStep(WizardStep):

    def __init__(self,
            template = 'confirm.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/save/',
            previous_url = '/ovmtb/templates/additional_packages/',
            next_url = '/ovmtb/templates/saveandbuild/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id):
        data = loadWork(request, project_id=project_id)
        if request.method == 'POST':
            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                clearWork(request, data=data, project_id=project_id)
                return HttpResponseRedirect(self.cancel_url)
            if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                base_url = self.save_url
            if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                base_url = self.previous_url
            if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                base_url = self.next_url

            saveWork(request, project_id=project_id, data=data)
            return HttpResponseRedirect(map_url(base_url, project_id))

        else:
            get_messages(request, self.context_params)

            self.context_params['project'] = data['TemplateProject']
            self.context_params['description'] = data['HardwareDescription']
            self.context_params['disk_list'] = data['disk_list']
            self.context_params['additional'] = ""
            for pack in data['package_list']:
                self.context_params['additional'] += "%s " %(pack.package_name)
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            saveWork(request, project_id=project_id, data=data)
            return HttpResponse(t.render(c))
