# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.forms import ModelForm, IntegerField, Select
from django.core.exceptions import ObjectDoesNotExist
from django.utils.translation import ugettext as _
from ovmtb.templates.models import HardwareDescription, TemplateProject, DiskImage
from ovmtb.templates.common import *
from ovmtb.templates.WizardStep import WizardStep
import datetime

class HardwareStep(WizardStep):
    '''The Description class implements the logic behind the 'OVM Template
    Project Description' page.
    '''
    
    def __init__(self,
            template = 'hardware.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/save/',
            previous_url = '/ovmtb/templates/description/',
            next_url = '/ovmtb/templates/install_sources/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url 
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id):        
        # Load the data from the session
        data = loadWork(request, project_id=project_id)

        if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
            clearWork(request, data=data, project_id=project_id)
            return HttpResponseRedirect(self.cancel_url)

        if request.method == 'POST':
            form = HardwareBaseForm(request.POST, instance=data['HardwareDescription'])
            if form.is_valid():
                data['HardwareDescription'] = form.save(commit=False)
                
                if 'deleteDiskButton' in request.POST:
                    if 'projectRadio' in request.POST:
                        disk = data['disk_list'].pop(int(request.POST['projectRadio']))
                        data['deleted_disks'].append(disk)
                        saveWork(request, project_id=project_id, data=data)
                        return HttpResponseRedirect(map_url('/ovmtb/templates/hardware/', project_id))
                    else:
                        saveWork(request, project_id=project_id, data=data)
                        log_info_message(request, _("Please select a disk from the list"))
                        return HttpResponseRedirect(map_url('/ovmtb/templates/hardware/', project_id))

                if 'editDiskButton' in request.POST:
                    if 'projectRadio' in request.POST:
                        disk_id = request.POST['projectRadio']
                        saveWork(request, project_id=project_id, data=data)
                        return HttpResponseRedirect(map_url('/ovmtb/templates/hardware_disks/disk%s/' %(disk_id), project_id))
                    else:
                        saveWork(request, project_id=project_id, data=data)
                        log_info_message(request, _("Please select a disk from the list"))
                        return HttpResponseRedirect(map_url('/ovmtb/templates/hardware/', project_id))
                
                if 'addDiskButton' in request.POST:
                    data['disk_list'].append(DiskImage(hardware_id=data['HardwareDescription']))
                    disk_id = len(data['disk_list']) - 1
                    base_url = '/ovmtb/templates/hardware_disks/disk%s/add/' %(disk_id)
                if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                    base_url = self.previous_url
                if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                    base_url = self.save_url
                if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                    base_url = self.next_url
                
                saveWork(request, project_id=project_id, data=data)
                return HttpResponseRedirect(map_url(base_url, project_id))

            else:
                self.context_params['form'] = form
                t = loader.get_template(self.template)
                get_messages(request, self.context_params)
                c = RequestContext(request, self.context_params)
                saveWork(request, project_id=project_id, data=data)
                return HttpResponse(t.render(c))

        else:
            form = HardwareBaseForm(instance=data['HardwareDescription'])
            self.context_params['form'] = form
            self.context_params['disk_list'] = data['disk_list']            
            self.context_params['project_id'] = project_id
            t = loader.get_template(self.template)
            get_messages(request, self.context_params)
            c = RequestContext(request, self.context_params)
            saveWork(request, project_id=project_id, data=data)
            return HttpResponse(t.render(c))

class HardwareBaseForm(ModelForm):
    system_disk = IntegerField(label=_("System disk size"))
    vcpus = IntegerField(label=_("VCPUs"), widget=Select(choices=HardwareDescription.VCPU_CHOICES))

    class Meta:
        model = HardwareDescription
        fields = ('vcpus', 'memory', 'system_disk', 'swap_space')

