# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.core.exceptions import ObjectDoesNotExist
from django.utils.translation import ugettext as _
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.resources.models import YUMRepo, DVDISOLocation
from ovmtb.templates.models import TemplateProject
from ovmtb.resources.YUMTableFormPage import cacheYUM
from ovmtb.resources.DVDTableFormPage import cacheDVD
from ovmtb.templates.common import *
import datetime

class InstallSourcesStep(WizardStep):
    def __init__(self,
            template = 'install_sources.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/save/',
            previous_url = '/ovmtb/templates/hardware/',
            next_url = '/ovmtb/templates/operating_system/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url 
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id):
        # Load the data from the session
        data = loadWork(request, project_id=project_id)
        project = data['TemplateProject']

        self.context_params['yum_list'] = YUMRepo.objects.all()
        self.context_params['dvd_list'] = DVDISOLocation.objects.all()

        if project.yum_repo:
            self.context_params['yum_checked'] = 'checked'
            self.context_params['selected_yum'] = project.yum_repo.id
        elif project.dvd_repo:
            self.context_params['dvd_checked'] = 'checked'
            self.context_params['selected_dvd'] = project.dvd_repo.id
            
        if request.method == 'POST':
            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                clearWork(request, data=data, project_id=project_id)
                return HttpResponseRedirect(self.cancel_url)

            try:
                if request.POST['selectInstallSource'] == "0":
                    project.yum_repo =  YUMRepo.objects.get(id=request.POST['selectYUM'])
                    project.dvd_repo = None
                    if 'nextButton2' in request.POST or 'nextButton1' in request.POST: 
                        try:
                            if not project.yum_repo.cached:
                                cacheYUM(project.yum_repo)
                                project.yum_repo.cached = datetime.datetime.now()
                                project.yum_repo.save()
                                log_info_message(request, _("Cached YUM repository %(r)s at %(c)s") %{'r':project.yum_repo, 'c':project.yum_repo.cached})
                        except Exception, e:
                            log_error_message(request, _("Could not cache YUM repository %(r)s: %(err)s") %{'r':project.yum_repo, 'err':e})
                            log_info_message(request, _("The repository selected could not be cached, if you wish to install packages from this repository please go to the Resource tab and verify that the repository can be cached."))
                elif request.POST['selectInstallSource'] == "1": 
                    project.dvd_repo =  DVDISOLocation.objects.get(id=request.POST['selectDVD'])
                    project.yum_repo = None
                    if 'nextButton2' in request.POST or 'nextButton1' in request.POST: 
                        try:
                            if not project.dvd_repo.cached:
                                cacheDVD(project.dvd_repo)
                                project.dvd_repo.cached = datetime.datetime.now()
                                project.dvd_repo.save()
                                log_info_message(request, _("Cached DVD ISO %(r)s at %(c)s") %{'r':project.dvd_repo, 'c':project.dvd_repo.cached})
                        except Exception, e:
                            log_error_message(request, _("Could not cache DVD ISO %(r)s: %(err)s") %{'r':project.dvd_repo, 'err':e})
                            log_info_message(request, _("The ISO selected could not be cached, if you wish to install packages from this ISO please go to the Resource tab and verify that the ISO can be cached."))
            except KeyError:
                if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                    log_info_message(request, _("No repository or ISO was selected.  If you wish to install packages please return to the previous screen and choose an installation source."))
                project.yum_repo = None
                project.dvd_repo = None

            saveWork(request, project_id=project_id, data=data)
            
            if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                base_url = self.previous_url
            if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                base_url = self.save_url
            if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                base_url = self.next_url
            return HttpResponseRedirect(map_url(base_url, project_id))

        else:
            saveWork(request, project_id=project_id, data=data)
            t = loader.get_template(self.template)
            get_messages(request, self.context_params)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))
