# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from ovmtb.templates.WizardStep import WizardStep
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from ovmtb.templates.models import TemplateProject
from ovmtb.templates.common import *
from django.forms import ModelForm, Form, FileField, ChoiceField, SelectMultiple
import yum, os

class OperatingSystemStep(WizardStep):

    def __init__(self,
            template = 'operating_system.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/save/',
            previous_url = '/ovmtb/templates/install_sources/',
            next_url = '/ovmtb/templates/additional_packages/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id):
        # Load the data from the session
        data = loadWork(request, project_id=project_id)
        project = data['TemplateProject']

        selected_packages_list = project.selected_packages.split()
        selected_groups_list = project.selected_groups.split()

        if project.yum_repo:
            yum_packages_list = project.yum_repo.packages.split()
            yum_groups_list = project.yum_repo.groups.split()
            available_packages_list = [p for p in yum_packages_list if p not in selected_packages_list]
            available_groups_list = [g for g in yum_groups_list if g not in selected_groups_list]
        elif project.dvd_repo:
            dvd_packages_list = project.dvd_repo.packages.split()
            dvd_groups_list = project.dvd_repo.groups.split()
            available_packages_list = [p for p in dvd_packages_list if p not in selected_packages_list]
            available_groups_list = [g for g in dvd_groups_list if g not in selected_groups_list]
        else:
            available_packages_list = []
            available_groups_list = []

        self.context_params['available_packages_list'] = available_packages_list
        self.context_params['selected_packages_list'] = selected_packages_list
        self.context_params['available_groups_list'] = available_groups_list
        self.context_params['selected_groups_list'] = selected_groups_list

        if request.method == 'POST':
            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                clearWork(request, data=data, project_id=project_id)
                return HttpResponseRedirect(self.cancel_url)
                
            if 'addGroupButton.x' in request.POST or 'addGroupButton.y' in request.POST:
                for grp in request.POST.getlist('availableGroups[]'):
                    self.context_params['selected_groups_list'].append(grp)
                project.selected_groups = " ".join(sorted(self.context_params['selected_groups_list']))
                base_url = "/ovmtb/templates/operating_system/"

            if 'addAllGroupsButton.x' in request.POST or 'addAllGroupsButton.y' in request.POST:
                for grp in self.context_params['available_groups_list']:
                    self.context_params['selected_groups_list'].append(grp)
                project.selected_groups = " ".join(sorted(self.context_params['selected_groups_list']))
                base_url = "/ovmtb/templates/operating_system/"

            if 'removeGroupButton.x' in request.POST or 'removeGroupButton.y' in request.POST:
                new_list = [p for p in self.context_params['selected_groups_list'] if p not in request.POST.getlist('selectedGroups[]')]
                project.selected_groups = " ".join(sorted(new_list))
                base_url = "/ovmtb/templates/operating_system/"

            if 'removeAllGroupsButton.x' in request.POST or 'removeAllGroupsButton.y' in request.POST:
                project.selected_groups = ""
                base_url = "/ovmtb/templates/operating_system/"

            if 'addPackageButton.x' in request.POST or 'addPackageButton.y' in request.POST:
                for pkg in request.POST.getlist('availablePackages[]'):
                    self.context_params['selected_packages_list'].append(pkg)
                project.selected_packages = " ".join(sorted(self.context_params['selected_packages_list']))
                base_url = "/ovmtb/templates/operating_system/"

            if 'addAllPackagesButton.x' in request.POST or 'addAllPackagesButton.y' in request.POST:
                for pkg in self.context_params['available_packages_list']:
                    self.context_params['selected_packages_list'].append(pkg)
                project.selected_packages = " ".join(sorted(self.context_params['selected_packages_list']))
                base_url = "/ovmtb/templates/operating_system/"

            if 'removePackageButton.x' in request.POST or 'removePackageButton.y' in request.POST:
                new_list = [p for p in self.context_params['selected_packages_list'] if p not in request.POST.getlist('selectedPackages[]')]
                project.selected_packages = " ".join(sorted(new_list))
                base_url = "/ovmtb/templates/operating_system/"

            if 'removeAllPackagesButton.x' in request.POST or 'removeAllPackagesButton.y' in request.POST:
                project.selected_packages = ""
                base_url = "/ovmtb/templates/operating_system/"

            if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                base_url = self.save_url
            if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                base_url = self.next_url
            if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                base_url = self.previous_url

            saveWork(request, project_id=project_id, data=data)
            
            return HttpResponseRedirect(map_url(base_url, project_id))
        
        else:
            saveWork(request, project_id=project_id, data=data)
            t = loader.get_template(self.template)
            get_messages(request, self.context_params)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))
