# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response
from django.forms import ModelForm
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.models import TemplateProject
from ovmtb.templates.common import *

class ProgressStep(WizardStep):

    def __init__(self,
            template = 'progress.html',
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '',
            save_url = '',
            previous_url = '/ovmtb/templates/progress/',
            next_url = '/ovmtb/templates/'):
        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.previous_url = previous_url
        self.next_url = next_url

    def generateResponse(self, request, project_id):
        get_messages(request, self.context_params)
        
        if request.method == 'POST':
            # The user pressed the returnButton or refreshButton
            if 'returnButton' in request.POST:
                return HttpResponseRedirect(self.next_url)
            else:
                return HttpResponseRedirect("%s%s" %(self.previous_url, project_id))

        # Otherwise this is the first visit to the page
        else:
            project = TemplateProject.objects.get(id=project_id)
            self.context_params['status'] = project.status
            self.context_params['percent'] = project.status_percent
            if project.logfile:
                f = open(project.logfile, "r")
                lines = f.readlines()
                f.close()
                text = "".join(lines)
                self.context_params['log'] = text
            else:
                self.context_params['log'] = "No log data"
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))
