# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render_to_response

class WizardStep:

    def __init__(self,
            template = None,
            context_params = {
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            },
            cancel_url = '/ovmtb/templates/',
            save_url = '/ovmtb/templates/',
            previous_url = None,
            next_url = None):

        self.template = template
        self.context_params = context_params
        self.cancel_url = cancel_url
        self.save_url = save_url
        self.next_url = next_url
        self.previous_url = previous_url

    def generateResponse(self, request, project_id=None):
        # The form will post to the same page.  We will need to handle the inputs for a POST request
        if request.method == 'POST':

            # If the input dictionary has a cancelButton* key, it means the user clicked the Cancel button
            # and should be redirected to the templates page
            if 'cancelButton2' in request.POST or 'cancelButton1' in request.POST:
                return HttpResponseRedirect(self.cancel_url)

            # If the input dictionary has a saveButton* key, it means the user clicked the Save button
            # data entered should be saved and then the user should be redirected to the templates page
            if 'saveButton2' in request.POST or 'saveButton1' in request.POST:
                # TODO ... save data
                return HttpResponseRedirect(self.save_url)

            # If the input dictionary has a previousButton* key, it means the user clicked the Previous button
            # data entered should be saved and then the user should be redirected to the Previous page
            if 'previousButton2' in request.POST or 'previousButton1' in request.POST:
                # TODO ... save data
                return HttpResponseRedirect(self.previous_url)

            # If the input dictionary has a nextButton* key, it means the user clicked the Next button
            # data entered should be saved and then the user should be redirected to the next page
            if 'nextButton2' in request.POST or 'nextButton1' in request.POST:
                # TODO ... save data
                return HttpResponseRedirect(self.next_url)

            else:
                t = loader.get_template(self.template)
                c = RequestContext(request, self.context_params)
                return HttpResponse(t.render(c))

        # Otherwise this is the first visit to the page
        else:
            t = loader.get_template(self.template)
            c = RequestContext(request, self.context_params)
            return HttpResponse(t.render(c))

