# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.db import models
from ovmtb.resources.models import YUMRepo, DVDISOLocation, JeOSImage
from django.utils.translation import ugettext as _
from django.contrib.auth.models import User

class TemplateProject(models.Model):
    STATUS_CHOICES = (
        ('COMP', _("Complete")),
        ('BLD', _("Build in progress")),
        ('BCOM', _("Build complete")),
        ('CCOM', _("Copy complete")),
        ('DCOM', _("Template definition complete")),
        ('JeOS', _("JeOS build in progress")),
        ('ERR', _("Error")),
        ('ERRB', _("Error during build")),
        ('PACK', _("Package installation in progress")),
        ('INPR', _("Template Definition in progress")),
        ('CLN', _("Template cleaned up")),
        ('CLNG', _("Template clean up in progress")),
        ('QUE', _("Template queued for build")),
    )

    template_name = models.CharField(default=_("New Template"), max_length=30)
    version = models.CharField(default="", max_length=30, blank=True, null=True)
    vendor = models.CharField(default="", max_length=50, blank=True, null=True)
    EULA = models.TextField(default="", blank=True, null=True)
    description = models.TextField(default="", blank=True)
    JeOS_image = models.ForeignKey(JeOSImage, null=True, blank=False)
    product = models.CharField(default="", max_length=50, blank=True)
    status = models.CharField(default="INPR", max_length=50, choices=STATUS_CHOICES)
    status_percent = models.IntegerField(default=0)
    logfile = models.CharField(default="", max_length=200, blank=True)
    builddir = models.CharField(default="", max_length=200, blank=True)
    upload_dir = models.CharField(default="", max_length=200, blank=True)
    tarfile = models.CharField(default="", max_length=200, blank=True)
    created = models.DateTimeField(auto_now_add=True)
    built = models.DateTimeField(null=True, blank=True)
    modified = models.DateTimeField(auto_now=True)
    selected_packages = models.TextField(default="", blank=True, editable = False)
    selected_groups = models.TextField(default="", blank=True, editable = False)
    yum_repo = models.ForeignKey(YUMRepo, null=True, blank=True)
    dvd_repo = models.ForeignKey(DVDISOLocation, null=True, blank=False)
    owner = models.ForeignKey(User)

    def __unicode__(self):
        return self.template_name

class HardwareDescription(models.Model):
    VCPU_CHOICES = (
        (1, 1),
        (2, 2),
        (4, 4),
        (8, 8),
        (16, 16),
        (32, 32),
        (128, 128),
    )

    template_project = models.OneToOneField(TemplateProject)
    vcpus = models.IntegerField(default=1, choices=VCPU_CHOICES)
    memory = models.IntegerField(default=512)
    system_disk = models.IntegerField(default=1024)
    swap_space = models.IntegerField(default=512)
    config_script = models.CharField(default="", max_length=200, blank=True, null=True)
    clean_up_script = models.CharField(default="", max_length=200, blank=True, null=True)
    
    def __unicode__(self):
        return self.template_project.template_name

class DiskImage(models.Model):
    hardware_id = models.ForeignKey(HardwareDescription)
    disk_image_file = models.CharField(default="data.img", max_length=100)
    mount_point = models.CharField(default="", blank=True, max_length=100)
    size = models.IntegerField(default=1024, null=True)
    
    def __unicode__(self):
        return self.disk_image_file

class UserPackage(models.Model):
    template_project = models.ForeignKey(TemplateProject)
    package_name = models.CharField(default="", blank=True, max_length=100, editable=False)
    package_file  = models.FileField(upload_to='ovmtb/data/uploads', blank=True, null=True)
    package_dir = models.CharField(default="", blank=True, max_length=20, editable=False)
    url  = models.URLField(default='', blank=True, null=True)

    def __unicode__(self):
        return self.package_name
