# Copyright (C) 2009 Oracle Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
from django.template import RequestContext, Context, loader
from django.http import HttpResponse, HttpResponseRedirect
from django import forms
from django.conf import settings
from django.shortcuts import render_to_response
from django.forms.util import ErrorList
from django.contrib.auth.decorators import login_required
from django.utils.translation import ugettext as _
from ovmtb.templates.models import *
from ovmtb.templates.WizardStep import WizardStep
from ovmtb.templates.common import *
from ovmtb.resources.models import JeOSImage
from ovmtb.admin.Daemon import checkBuildDaemonStatus
from ovmtb import settings
from threading import Thread
from time import sleep
import datetime, logging, shutil

@login_required
def templates(request):
    image_list = JeOSImage.objects.all()

    # The form will post to the same page.  We will need to handle the inputs for a POST request
    if request.method == 'POST':

        if 'clearSearchButton' in request.POST:
            project_list = TemplateProject.objects.all().filter(owner__id__exact=request.user.id)
            t = loader.get_template('templates.html')
            c = RequestContext(request, {
                'project_list': project_list,
                'image_list': image_list,
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            })
            return HttpResponse(t.render(c))

        if 'searchButton' in request.POST:
            if request.POST['JeOSFilter'] and not request.POST['nameFilter']:
                project_list = TemplateProject.objects.filter(JeOS_image__image_name__exact=request.POST['JeOSFilter'])
            elif not request.POST['JeOSFilter'] and request.POST['nameFilter']:
                project_list = TemplateProject.objects.filter(template_name__icontains=request.POST['nameFilter'])
            elif request.POST['JeOSFilter'] and request.POST['nameFilter']:
                project_list = TemplateProject.objects.filter(JeOS_image__image_name__exact=request.POST['JeOSFilter']).filter(template_name__contains=request.POST['nameFilter'])
            else:
                project_list = TemplateProject.objects.all()

            project_list = project_list.filter(owner__id__exact=request.user.id)
            t = loader.get_template('templates.html')
            c = RequestContext(request, {
                'project_list': project_list,
                'image_list': image_list,
                'search': True,
                'tab_template': "templates_tab_active.html",
                'submenu_template': "no_submenu.html",
            })
            return HttpResponse(t.render(c))

        if 'editButton' in request.POST:
            try:
                project = TemplateProject.objects.get(id=request.POST['projectRadio'])
                return HttpResponseRedirect('/ovmtb/templates/description/%d/' %(project.id))
            except KeyError:
                log_info_message(_("Please select an item from the list"))
                return HttpResponseRedirect('/ovmtb/templates/')

        if 'deleteButton' in request.POST:
            try:
                project =  TemplateProject.objects.get(id=request.POST['projectRadio'])
                deletefile = open('%s/delete_project_%s' %(settings.OVMTB_BUILD_QUEUE_DIR, project.id), "w")
                if project.builddir:
                    deletefile.write("%s/%s\n" %(settings.OVMTB_BUILD_DIR, os.path.basename(project.builddir)))
                if project.tarfile:
                    deletefile.write("%s/%s\n" %(settings.OVMTB_TAR_DIR, os.path.basename(project.tarfile)))
                if project.logfile:
                    deletefile.write("%s/%s\n" %(settings.OVMTB_LOG_DIR, os.path.basename(project.logfile)))
                if project.upload_dir:
                    deletefile.write("%s\n" %(project.upload_dir))
                deletefile.close()
                project.delete()
                log_info_message(request, _("Deleted template project: %(name)s") % {'name':project.template_name,})
            except KeyError:
                log_info_message(request, _("Please select an item from the list"))
            return HttpResponseRedirect('/ovmtb/templates/')

        if 'buildButton' in request.POST:
            try:
                project = TemplateProject.objects.get(id=request.POST['projectRadio'])
                return HttpResponseRedirect('/ovmtb/templates/build/%s' %(project.id))
            except KeyError:
                log_info_message(request, _("Please select an item from the list"))
                return HttpResponseRedirect('/ovmtb/templates/')

        if 'cleanButton' in request.POST:
            try:
                project = TemplateProject.objects.get(id=request.POST['projectRadio'])
                return HttpResponseRedirect('/ovmtb/templates/clean/%s' %(project.id))
            except KeyError:
                log_info_message(_("Please select an item from the list"))
                return HttpResponseRedirect('/ovmtb/templates/')

        if 'copyButton' in request.POST:
            try:
                orig = TemplateProject.objects.get(id=request.POST['projectRadio'])
            except KeyError:
                log_info_message(_("Please select an item from the list"))
                return HttpResponseRedirect('/ovmtb/templates/')

            # Start by copying the template object
            copy = TemplateProject(template_name = orig.template_name,
                version = orig.version,
                vendor = orig.vendor,
                EULA = orig.EULA,
                description = orig.description,
                JeOS_image = orig.JeOS_image,
                product = orig.product,
                status = 'CCOM',
                status_percent = 0,
                logfile = "",
                builddir = "",
                tarfile = "",
                created = orig.created,
                modified = datetime.datetime.now(),
                built = None,
                owner = orig.owner,
                yum_repo = orig.yum_repo,
                dvd_repo = orig.dvd_repo,
                selected_packages = orig.selected_packages,
                selected_groups = orig.selected_groups,
            )
            
            # Now I need a new upload_dir
            save_dir = '%s/%s' %(settings.OVMTB_UPLOAD_DIR, generateRandomDir())
            while not checkDir(save_dir):
                save_dir = '%s/%s' %(settings.OVMTB_UPLOAD_DIR, generateRandomDir())
            copy.upload_dir = save_dir
            
            copy.save()

            # Now copy hardware object
            hard_orig = HardwareDescription.objects.get(template_project__id__exact=orig.id)
            hard_copy = HardwareDescription(
                template_project=copy,
                vcpus=hard_orig.vcpus,
                memory = hard_orig.memory,
                system_disk = hard_orig.system_disk,
                swap_space = hard_orig.swap_space,
                clean_up_script = hard_orig.clean_up_script,
                config_script = hard_orig.config_script
            )
            hard_copy.save()

            # Now we need to copy all disks for the HardwareDescription
            orig_disk_images = DiskImage.objects.filter(hardware_id__id__exact=hard_orig.id)
            for image in orig_disk_images:
                disk_copy = DiskImage(
                    hardware_id=hard_copy,
                    disk_image_file=image.disk_image_file,
                    mount_point = image.mount_point,
                    size = image.size,
                )
                disk_copy.save()

            # Now we need to copy all UserPackage
            orig_user_packages = UserPackage.objects.filter(template_project__id__exact=hard_orig.id)
            for pack in orig_user_packages:
                pack_copy = UserPackage(
                    template_project = copy,
                    package_name = pack.package_name,
                    package_dir = copy.upload_dir,
                    url = pack.url
                )
                fname = os.path.basename(pack.package_file._get_path())
                shutil.copy(pack.package_file._get_path(), "%s/%s" %(copy.upload_dir, fname))
                pack_copy.package_file = ("%s/%s" %(copy.upload_dir, fname))
                pack_copy.save()

            # Redirect to the base page
            return HttpResponseRedirect('/ovmtb/templates/')

        if 'newTemplateButton1' in request.POST or 'newTemplateButton2' in request.POST:
            newProjectInSession(request)
            return HttpResponseRedirect('/ovmtb/templates/description/')

        if 'refreshButton1' in request.POST or 'refreshButton2' in request.POST:
            return HttpResponseRedirect('/ovmtb/templates/')

    # Otherwise this is the first visit to the page
    else:
        project_list = TemplateProject.objects.all().filter(owner__id__exact=request.user.id)
        t = loader.get_template('templates.html')
        context_params = {
            'project_list': project_list,
            'image_list': image_list,
            'tab_template': "templates_tab_active.html",
            'submenu_template': "no_submenu.html",
        }
        try:
            context_params['error_messages'] = request.session['error_messages']
            del request.session['error_messages']
        except KeyError:
            pass
        try:
            context_params['info_messages'] = request.session['info_messages']
            del request.session['info_messages']
        except KeyError:
            pass
        c = RequestContext(request, context_params)
        return HttpResponse(t.render(c))

@login_required
def build(request, project_id):
    project = TemplateProject.objects.get(id=project_id)
    if checkBuildDaemonStatus():
        try:
            buildfile = open('%s/build_project_%s' %(settings.OVMTB_BUILD_QUEUE_DIR, project_id), "w")
            buildfile.write("%s" %(project_id))
            buildfile.close()
            project.builddir = ""
            project.tarfile = ""
            project.logfile = ""
            project.status = "QUE"
            project.status_percent = 0
            project.save()
            return HttpResponseRedirect('/ovmtb/templates/progress/%s/' %(project_id))
        except IOError, e:
            log_error_message(request, _("Could not start build for \"%(name)s\": Unable to queue build file: %(e)s") %{'name':project.template_name, 'e':e})
            return HttpResponseRedirect('/ovmtb/templates/')
    else:
        log_error_message(request, _("Could not start build for \"%(name)s\": build daemon does not appear to be running.  Please check build daemon status.") %{'name':project.template_name})
        return HttpResponseRedirect('/ovmtb/templates/')

@login_required
def clean(request, project_id):
    project = TemplateProject.objects.get(id=project_id)
    project.status = 'CLNG'
    project.status_percent = 0
    project.save()

    buildfile = open('%s/clean_project_%s' %(settings.OVMTB_BUILD_QUEUE_DIR, project_id), "w")
    buildfile.write("%s" %(project_id))
    buildfile.close()
    return HttpResponseRedirect('/ovmtb/templates/')

@login_required
def __save(request, project_id=None):
    data = loadWork(request, project_id=project_id)
    data['TemplateProject'].status = 'DCOM'
    data['TemplateProject'].save()
    id = data['TemplateProject'].id
    data['HardwareDescription'].template_project = data['TemplateProject']
    data['HardwareDescription'].save()
    
    for disk in data['disk_list']:
        disk.hardware_id = data['HardwareDescription']
        disk.save()
    for disk in data['deleted_disks']:
        try:
            disk.delete()
        except Exception:
            pass

    for package in data['package_list']:
        package.template_project = data['TemplateProject']
        package.save()
    for package in data['deleted_packages']:
        try:
            package.delete()
        except Exception:
            pass

    clearWork(request, project_id=project_id)
    return id

@login_required
def save(request, project_id=None):
    __save(request, project_id)
    return HttpResponseRedirect('/ovmtb/templates/')

@login_required
def saveAndBuild(request, project_id=None):
    id = __save(request, project_id)
    return HttpResponseRedirect('/ovmtb/templates/build/%s/' %(id))

@login_required
def basic_step(request, step_class, project_id=None, disk_id=None, type=None):
    obj = step_class()
    if disk_id:
        return obj.generateResponse(request, disk_id, type, project_id)
    else:
        return obj.generateResponse(request, project_id)
